Functions
=========

All functions infer float precision based on the input (``np.float32`` or ``np.float64``).

.. currentmodule:: pysplashsurf

.. autofunction:: barnacle_decimation

.. autofunction:: check_mesh_consistency

.. autofunction:: convert_tris_to_quads

.. autofunction:: laplacian_smoothing_normals_parallel

.. autofunction:: laplacian_smoothing_parallel

.. autofunction:: marching_cubes

.. autofunction:: marching_cubes_cleanup

.. autofunction:: neighborhood_search_spatial_hashing_parallel

.. autofunction:: reconstruct_surface

.. autofunction:: reconstruction_pipeline
